#
# spec file for package prelude-lml
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           prelude-lml
Version:        5.2.0
Release:        2.2
Summary:        The prelude log analyzer
# Prelude is GPL-2.0+
# libmissing is LGPL-2.1+
# libmissing/test is GPL-3.0+
License:        GPL-2.0-or-later AND LGPL-2.1-only AND GPL-3.0-or-later
Group:          System/Daemons
URL:            https://www.prelude-siem.org
Source0:        https://www.prelude-siem.org/pkg/src/%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.service
Source2:        %{name}-tmpfiles.conf
Source3:        https://www.prelude-siem.org/pkg/src/%{version}/%{name}-%{version}.tar.gz.sig
Source4:        https://www.prelude-siem.org/attachments/download/233/RPM-GPG-KEY-Prelude-IDS#/%{name}.keyring
# Add default syslog format to work out of the box
Patch0:         %{name}-conf_rsyslog.patch
# Fix make check
Patch1:         %{name}-fix_check.patch
# Fix etc files permissions
Patch2:         %{name}-fix_etc_perms.patch
BuildRequires:  gamin-devel
BuildRequires:  libprelude-devel >= 5.2.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gnutls) >= 1.0.17
BuildRequires:  pkgconfig(icu-io) >= 3.0
BuildRequires:  pkgconfig(libpcre) >= 4.1
BuildRequires:  pkgconfig(systemd)
%{?systemd_ordering}

%description
Prelude-LML is a log analyser that allows Prelude to collect and
analyze information from all kind of applications emitting logs or
syslog messages in order to detect suspicious activities and transform
them into Prelude-IDMEF alerts. Prelude-LML handles events generated
by a large set of applications

%package devel
Summary:        Header files and libraries for prelude-lml development
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}
Requires:       libprelude-devel >= 5.2.0

%description devel
Libraries, include files, etc you can use to develop custom
Prelude LML plugins.

%prep
%setup -q
%patch0
%patch1
%patch2

%build
%configure
%make_build

%install
mkdir -p %{buildroot}/%{_sysconfdir}/%{name}/ruleset/
mkdir -p %{buildroot}/%{_sbindir}
%make_install
rm -f %{buildroot}/%{_libdir}/%{name}/debug.la
rm -f %{buildroot}/%{_libdir}/%{name}/pcre.la
install -d -m 0755 %{buildroot}/%{_tmpfilesdir}
install -m 0644 %{SOURCE2} %{buildroot}/%{_tmpfilesdir}/%{name}.conf
mkdir -p %{buildroot}/%{_var}/lib/%{name}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
rm -rf %{buildroot}/%{_localstatedir}/run/%{name}
install -D -m 444 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service

%pre
%service_add_pre %{name}.service

%post
/sbin/ldconfig
%{_bindir}/systemd-tmpfiles --create %{_tmpfilesdir}/%{name}.conf
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
/sbin/ldconfig
%service_del_postun %{name}.service

%files
%license COPYING
%doc NEWS HACKING.README README
%attr(0770,-,-) %dir %{_sysconfdir}/%{name}/
%config(noreplace) %attr(0640,-,-) %{_sysconfdir}/%{name}/plugins.rules
%config(noreplace) %attr(0640,-,-) %{_sysconfdir}/%{name}/%{name}.conf
%attr(0770,-,-) %dir %{_sysconfdir}/%{name}/ruleset/
%{_bindir}/%{name}
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/debug.so
%{_libdir}/%{name}/pcre.so
%{_sbindir}/rc%{name}
%dir %{_tmpfilesdir}
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}.service
%dir %{_var}/lib/%{name}
%ghost /run/%{name}

%files devel
%license COPYING
%dir %{_includedir}/%{name}/
%{_includedir}/%{name}/%{name}.h

%changelog
* Wed Oct 20 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * prelude-lml.service
* Sun Oct 25 2020 Andreas Stieger <andreas.stieger@gmx.de>
- prelude-lml 5.2.0:
  * Fix max-rotation-size-offset parsing
  * Document the log-max-length option
- add upstream signing key and verify source signature
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Fri Oct 25 2019 thomas.andrejak@gmail.com
  Bump version 5.1.0
  - Support of Syslog priority field
  - Fix support of AdditionalData
  - Update SELinux policies
- Bump spec copyright to 2019
- Update License field
* Wed Oct  4 2017 thomas.andrejak@gmail.com
- Update to 4.0.0
- Rename source prelude-lml.run to prelude-lml-tmpfiles.conf
- Clean prelude-lml.service
- Add patchs:
  - prelude-lml-fix_check.patch: Fix make check
  - prelude-lml-fix_etc_perms.patch: Fix Prelude LML dirs permissions
* Thu Mar 23 2017 aj@ajaissle.de
- Added %%ghost /run/%%{name}
* Fri Feb 10 2017 thomas.andrejak@gmail.com
- Update to 3.1.0 (Prelude 3.1.0 released on 14 Sept 2016)
- Add missing /var/lib/prelude-lml dir
- Remove unnecessary spool directory
- Patch the configuration to be naturally OK with rsyslog
  prelude-lml-conf_rsyslog.patch
- Spec-Cleaner
* Thu Jan 26 2017 jengelh@inai.de
- Use SUSE RPM group names
* Thu Sep 15 2016 thomas.andrejak@gmail.com
- Update licence from GPL-2.0+ to GPL-3.0+ to include libmissing
* Sun Sep  4 2016 thomas.andrejak@gmail.com
  Remove Selinux since it should be directly in Security:SELinux
  Clean usage of "-n %%{name}-"
* Tue May  3 2016 thomas.andrejak@gmail.com
  Initial import
  Add systemd files because it is a daemon.
  Also package SELinux files.
